@@ -36,7 +36,7 @@ static void abort_dialog_clicked(GtkWidget *widget,gpointer user_data)
 
 GtkWidget *abort_dialog(gchar *label)
 {
-	GtkWidget *dialog,*button,*hbox,*vbox;
+	GtkWidget *dialog,*button;
 
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
@@ -49,11 +49,8 @@ GtkWidget *abort_dialog(gchar *label)
 	GTK_WIDGET_SET_FLAGS(button,GTK_CAN_DEFAULT);
 
 	/* ե졼ȥܥå */
-	vbox=gtk_vbox_new(FALSE,0);
-	hbox=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,8);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,8);
-	gtk_container_add(GTK_CONTAINER(dialog),vbox);
+	gtk_container_set_border_width(GTK_CONTAINER(button),8);
+	gtk_container_add(GTK_CONTAINER(dialog),button);
 
 	/* ɽ */
 	gtk_widget_grab_focus(button);
