@@ -24,6 +24,7 @@
 #include "find.h"
 #include "general.h"
 #include "other.h"
+#include "signal.h"
 
 
 gboolean find_arrow=TRUE;					/*  */
@@ -445,7 +446,11 @@ void find_operation(TEXTWND *ptw,GdkPoint *start,GdkPoint *end,
 			ptw->top.y=ptw->cursor.y;
 		else if (ptw->cursor.y-sy+1>ptw->top.y)
 			ptw->top.y=ptw->cursor.y-sy+1;
-		move_text_window(ptw,&top);
+		move_edit_window(ptw,&top);
+		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+										0,get_width_max(ptw),sx,ptw->top.x);
+		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+										0,ptw->max-1,sy,ptw->top.y);
 		clear_sel(ptw,&ptw->select,&ptw->cursor);
 		draw_caret(ptw,&cursor);
 		gtk_selection_owner_set(ptw->drawing,GDK_SELECTION_PRIMARY,
