@@ -64,7 +64,7 @@ void draw_caret(TEXTWND *ptw,GdkPoint *cursor)
 	guint context_id;
 	GdkRectangle rc;
 
-	if (cursor!=NULL
+	if (cursor!=NULL && timer_id!=0
 				&& (ptw->cursor.x!=cursor->x || ptw->cursor.y!=cursor->y)) {
 		/* ޺ */
 		gtk_timeout_remove(timer_id);
@@ -257,23 +257,14 @@ void clear_sel(TEXTWND *ptw,GdkPoint *start,GdkPoint *end)
 /*	ư
 	ptw,TXTɥ
 	top,Ťκɸ														*/
-void move_text_window(TEXTWND *ptw,GdkPoint *top)
+void move_edit_window(TEXTWND *ptw,GdkPoint *top)
 {
-	gint sx,sy;
-
-	sx=MAX(ptw->drawing->allocation.width/ptw->fontwidth,1);
-	sy=MAX(ptw->drawing->allocation.height/ptw->fontheight,1);
-	if (ptw->top.x!=top->x || ptw->top.y!=top->y) {
-		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
-										0,get_width_max(ptw),sx,ptw->top.x);
-		set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
-										0,ptw->max-1,sy,ptw->top.y);
+	if (ptw->top.x!=top->x || ptw->top.y!=top->y)
 		scroll_window(ptw->drawing,	(top->x-ptw->top.x)*ptw->fontwidth,
 									(top->y-ptw->top.y)*ptw->fontheight,
 									0,0,
 									ptw->drawing->allocation.width,
 									ptw->drawing->allocation.height);
-	}
 }
 
 
@@ -412,11 +403,11 @@ DOING *edit_operation(TEXTWND *ptw,gchar *text,gint length,
 	max=get_width_max(ptw);
 	if (ptw->top.x>max-sx+1)
 		ptw->top.x=MAX(max-sx+1,0);
+	move_edit_window(ptw,&top);
 	set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
 												0,max,sx,ptw->top.x);
 	set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
 												0,ptw->max-1,sy,ptw->top.y);
-	move_text_window(ptw,&top);
 	draw_caret(ptw,NULL);
 	return d;
 }
