@@ -187,7 +187,7 @@ void set_scroll_bar(GtkWidget *scroll,GtkSignalFunc func,gpointer func_data,
 {
 	GtkObject *adjust;
 
-	adjust=gtk_adjustment_new(pos,min,max,1,page,page-1);
+	adjust=gtk_adjustment_new(pos,min,max,1,page,page);
 	gtk_range_set_adjustment(GTK_RANGE(scroll),GTK_ADJUSTMENT(adjust));
 	gtk_range_slider_update(GTK_RANGE(scroll));
 	if (func!=NULL)
