@@ -258,9 +258,7 @@ gboolean print_dialog(PRNCFG *prncfg)
 	check=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
 													_("ϰϤ(_S)"));
-	gtk_widget_add_accelerator(check,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),prncfg->select);
 	gtk_signal_connect(GTK_OBJECT(check),"toggled",
 												print_dialog_toggled,prncfg);
@@ -343,14 +341,10 @@ gboolean print_dialog(PRNCFG *prncfg)
 												GTK_RADIO_BUTTON(radio0),NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
 															_("ץ(_P)"));
-	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),
 															_("ե(_F)"));
-	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",
 												print_dialog_toggled,prncfg);
 	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",
@@ -367,33 +361,19 @@ gboolean print_dialog(PRNCFG *prncfg)
 	label6=gtk_label_new(NULL);
 	label7=gtk_label_new(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(label0),_("(_C)"));
-	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label2),_("(_W)"));
-	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin1,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label3),_("⤵(_H)"));
-	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label4),_("(_T)"));
-	gtk_widget_add_accelerator(spin3,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin3,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label5),_("(_L)"));
-	gtk_widget_add_accelerator(spin4,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin4,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label6),_("(_R)"));
-	gtk_widget_add_accelerator(spin5,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin5,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label7),_("(_B)"));
-	gtk_widget_add_accelerator(spin6,"grab-focus",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(spin6,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	/* ܥܥå */
 	for (i=0;paper[i].name!=NULL;i++)
 		glist=g_list_append(glist,paper[i].name);
