@@ -25,9 +25,10 @@
 
 
 typedef struct prncfg {
-	gboolean mode;
+	gboolean mode,select;
 	gchar *printer,*file;
-	gint column,width,height,left,top,right,bottom;
+	gint width,height,left,top,right,bottom;
+	gint column,fontwidth,fontheight;
 } PRNCFG;
 
 
@@ -35,6 +36,7 @@ extern PRNCFG printer;					/* ̐ݒ */
 
 
 gboolean print_dialog(PRNCFG *prncfg);
+gboolean print_out(TEXTWND *ptw,PRNCFG *prncfg);
 
 
 #endif
