@@ -71,19 +71,13 @@ gint repinfo_dialog(REPINFO *ri)
 	button3=gtk_button_new_with_label(_(""));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("ִ(_R)"));
-	gtk_widget_add_accelerator(button0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
 																_("(_N)"));
-	gtk_widget_add_accelerator(button1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),
 														_("٤ִ(_A)"));
-	gtk_widget_add_accelerator(button2,"clicked",accel,'A',
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button2,"clicked",accel,'A',GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 										repinfo_dialog_clicked,(gpointer)1);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
@@ -97,7 +91,7 @@ gint repinfo_dialog(REPINFO *ri)
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button3,GTK_CAN_DEFAULT);
 	/* ե졼ȥܥå */
-	tbox=gtk_vbox_new(FALSE,0);
+	tbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(tbox),8);
 	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_start(GTK_BOX(hbox),
