@@ -112,14 +112,10 @@ gint replace_dialog(REPLACE *rp)
 	button2=gtk_button_new_with_label(_(""));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("ִ(_R)"));
-	gtk_widget_add_accelerator(button0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),
 														_("٤ִ(_A)"));
-	gtk_widget_add_accelerator(button1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
 												replace_dialog_clicked_ok,rp);
 	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
@@ -133,9 +129,7 @@ gint replace_dialog(REPLACE *rp)
 	check=gtk_check_button_new_with_label(NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
 											_("ʸ/ʸ̤(_C)"));
-	gtk_widget_add_accelerator(check,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),rp->ignorecase);
 	/* ܥܥå */
 	for (i=0;i<find_num;i++)
@@ -167,13 +161,9 @@ gint replace_dialog(REPLACE *rp)
 	radio1=gtk_radio_button_new_with_label_from_widget(
 												GTK_RADIO_BUTTON(radio0),NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("(_U)"));
-	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("(_D)"));
-	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(rp->arrow?radio1:radio0),
 																		TRUE);
 	/* ե졼ȥܥå */
