@@ -153,7 +153,7 @@ void signal_value_changed_hscroll(GtkAdjustment *adjust,TEXTWND *ptw)
 
 	top=ptw->top;
 	ptw->top.x=adjust->value;
-	move_text_window(ptw,&top);
+	move_edit_window(ptw,&top);
 	draw_caret(ptw,NULL);
 }
 
@@ -164,12 +164,15 @@ void signal_value_changed_vscroll(GtkAdjustment *adjust,TEXTWND *ptw)
 	GdkPoint top;
 
 	top=ptw->top;
-	ptw->top.y=adjust->value;
+	ptw->top.y=adjust->value+0.5;
 	sx=MAX(ptw->drawing->allocation.width/ptw->fontwidth,1);
 	max=get_width_max(ptw);
 	if (ptw->top.x>max-sx+1)
 		ptw->top.x=MAX(max-sx+1,0);
-	move_text_window(ptw,&top);
+	move_edit_window(ptw,&top);
+	if (ptw->top.x!=top.x)
+		set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+														0,max,sx,ptw->top.x);
 	draw_caret(ptw,NULL);
 }
 
@@ -581,7 +584,13 @@ gboolean signal_button_press(GtkWidget *widget,
 				max=get_width_max(ptw);
 				if (ptw->top.x>max-sx+1)
 					ptw->top.x=MAX(max-sx+1,0);
-				move_text_window(ptw,&top);
+				move_edit_window(ptw,&top);
+				if (ptw->top.x!=top.x)
+					set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,
+											ptw,0,max,sx,ptw->top.x);
+				if (ptw->top.y!=top.y)
+					set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,
+											ptw,0,ptw->max-1,sy,ptw->top.y);
 				draw_caret(ptw,NULL);
 			}
 		}
@@ -741,7 +750,13 @@ static gboolean signal_motion_notify_draw(TEXTWND *ptw,gint x,gint y,
 	if (ptw->cursor.x!=cursor.x || ptw->cursor.y!=cursor.y
 								|| ptw->top.x!=top.x || ptw->top.y!=top.y) {
 		set_menu_bar(ptw);
-		move_text_window(ptw,&top);
+		move_edit_window(ptw,&top);
+		if (ptw->top.x!=top.x)
+			set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+										0,get_width_max(ptw),sx,ptw->top.x);
+		if (ptw->top.y!=top.y)
+			set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+										0,ptw->max-1,sy,ptw->top.y);
 		draw_caret(ptw,&cursor);
 		clear_sel(ptw,&ptw->cursor,&cursor);
 	}
@@ -993,7 +1008,13 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				break;
 			if (ptw->select.x!=select.x)
 				set_menu_bar(ptw);
-			move_text_window(ptw,&top);
+			move_edit_window(ptw,&top);
+			if (ptw->top.x!=top.x)
+				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+										0,get_width_max(ptw),sx,ptw->top.x);
+			if (ptw->top.y!=top.y)
+				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+										0,ptw->max-1,sy,ptw->top.y);
 			draw_caret(ptw,&cursor);
 			if (select.x>=0 && ptw->select.x<0)
 				clear_sel(ptw,&select,&cursor);
@@ -1076,7 +1097,13 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				ptw->top.y=ptw->cursor.y-sy+1;
 			ptw->select.x=-1;
 			set_menu_bar(ptw);
-			move_text_window(ptw,&top);
+			move_edit_window(ptw,&top);
+			if (ptw->top.x!=top.x)
+				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+										0,get_width_max(ptw),sx,ptw->top.x);
+			if (ptw->top.y!=top.y)
+				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+										0,ptw->max-1,sy,ptw->top.y);
 			clear_sel(ptw,&select,&ptw->cursor);
 			draw_caret(ptw,NULL);
 		}
@@ -1172,7 +1199,13 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,TEXTWND *ptw)
 				ptw->top.y=ptw->cursor.y;
 			else if (ptw->cursor.y-sy+1>ptw->top.y)
 				ptw->top.y=ptw->cursor.y-sy+1;
-			move_text_window(ptw,&top);
+			move_edit_window(ptw,&top);
+			if (ptw->top.x!=top.x)
+				set_scroll_bar(ptw->hscroll,signal_value_changed_hscroll,ptw,
+										0,get_width_max(ptw),sx,ptw->top.x);
+			if (ptw->top.y!=top.y)
+				set_scroll_bar(ptw->vscroll,signal_value_changed_vscroll,ptw,
+										0,ptw->max-1,sy,ptw->top.y);
 		}
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(
 				item_factory_popup,_("<main>/᤹(U)")),ptw->undo!=NULL);
