@@ -448,8 +448,8 @@ int main(int argc,char *argv[])
 												|| g_strcasecmp(arg,"YES")==0;
 						break;
 					case 's':
-						def_height=strtol(arg,&endptr,0);
-						def_width=strtol(++endptr,&endptr,0);
+						def_width=strtol(arg,&endptr,0);
+						def_height=strtol(++endptr,&endptr,0);
 						break;
 					case 'x':
 						second=g_strcasecmp(arg,"OK")==0
@@ -540,6 +540,8 @@ int main(int argc,char *argv[])
 	atom_text=gdk_atom_intern("TEXT",FALSE);
 	atom_textmaid=gdk_atom_intern("Text maid InterProcess communication",
 																		FALSE);
+	gtk_selection_add_targets(window,GDK_SELECTION_PRIMARY,
+							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	gtk_selection_add_targets(window,atom_clipboard,
 							targets,sizeof(targets)/sizeof(GtkTargetEntry));
 	if (!second)
