@@ -114,6 +114,8 @@ gboolean valchr_dialog(gchar *valchr)
 										valchr_dialog_clicked_ok,valchr);
 	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
 										gtk_widget_destroy,GTK_OBJECT(dialog));
+	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
+	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ȥ꡼ */
 	entry=gtk_entry_new_with_max_length(4);
 	text=valstr(valchr_default,valchr_base,0,FALSE);
@@ -130,19 +132,13 @@ gboolean valchr_dialog(gchar *valchr)
 												GTK_RADIO_BUTTON(radio1),NULL);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
 															_("16ʿ(_H)"));
-	gtk_widget_add_accelerator(radio0,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),
 															_("10ʿ(_T)"));
-	gtk_widget_add_accelerator(radio1,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio2)->child),
 															_("8ʿ(_Q)"));
-	gtk_widget_add_accelerator(radio2,"clicked",accel,key,
-									GDK_MOD1_MASK|GDK_MOD2_MASK|GDK_MOD3_MASK
-											|GDK_MOD4_MASK|GDK_MOD5_MASK,0);
+	gtk_widget_add_accelerator(radio2,"clicked",accel,key,GDK_MOD1_MASK,0);
 	switch (valchr_base) {
 	case 16:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio0),TRUE);break;
 	case 10:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1),TRUE);break;
